"""
(c) 2023 LLC «DACOM M»
"""

import os
import yaml

from veilrpc.utils.bazalt import states_response, CommandExecutionError, LOCAL_MODULES_PATH, \
    get_output, BASE_PUPPET_PATH

LOCAL_GRAFANA_PATH = f'{LOCAL_MODULES_PATH}/grafana.yaml'
DEFAULT_GRAFANA_CONF = f'{BASE_PUPPET_PATH}/grafana.yaml'


def _apply():
    ret = get_output('systemctl restart grafana-server.service')
    if not ret['result']:
        raise CommandExecutionError(ret['comment'])


@states_response
def grafana_get_param(param, **kwargs):
    cmd = f"grep -r '^{param}' /etc/grafana/ldap.toml | awk '{{print $3}}'"
    resp = get_output(cmd, **kwargs)
    if not resp['result']:
        raise CommandExecutionError(resp['comment'])
    value = resp['comment'].strip()
    try:
        return int(value)
    except ValueError:
        return value


def _grafana_config_settings():
    settings = dict()
    resp = grafana_get_param(param='host')
    if resp['result']:
        settings['host'] = resp['comment']
    resp = grafana_get_param(param='port')
    if resp['result']:
        settings['port'] = resp['comment']
    resp = grafana_get_param(param='bind_dn')
    if resp['result']:
        settings['bind_dn'] = resp['comment']
    resp = grafana_get_param(param='search_filter')
    if resp['result']:
        settings['search_filter'] = resp['comment']
    resp = grafana_get_param(param='search_base_dns')
    if resp['result']:
        settings['search_base_dns'] = resp['comment']
    return settings


@states_response
def ldap_enable(host, bind_dn, search_filter, search_base_dns, port=389):
    pass
    # cmd = "sed -i -r 's/.*reporting_enabled.*/reporting_enabled = false/g' /etc/grafana/grafana.ini"
    # os.system(cmd)


def _create_grafana_yaml():
    if not os.path.exists(LOCAL_GRAFANA_PATH):
        with open(DEFAULT_GRAFANA_CONF, 'r') as f:
            default_grafana_conf = yaml.safe_load(f)
        for yaml_param, default_value in default_grafana_conf.items():
            for param, value in _grafana_config_settings().items():
                if param in yaml_param and value != default_value:
                    default_grafana_conf[yaml_param] = value
        with open(LOCAL_GRAFANA_PATH, 'w') as f:
            f.write(yaml.dump(default_grafana_conf))
