"""
(c) 2023 LLC «DACOM M»
"""
from veilrpc.utils.bazalt import states_response, get_output, CommandExecutionError, ROLE_SCRIPT_PATH, action_service
from veilrpc.states.puppet import puppet_eyaml_common
from veilrpc.states.services import NODE_SERVICES, CONTROLLER_SERVICES


def restart_services(controller: bool = False, node: bool = False):
    if controller:
        ctr_services = [s[1] for s in CONTROLLER_SERVICES]
        ret = action_service(" ".join(ctr_services), 'restart')
        if not ret['result']:
            raise CommandExecutionError(ret['comment'])
    if node:
        node_services = [s[1] for s in NODE_SERVICES]
        ret = action_service(" ".join(node_services), 'restart')
        if not ret['result']:
            raise CommandExecutionError(ret['comment'])


@states_response
def change_db_password(db_name: str = 'veildb', db_user: str = 'veil', password: str = None,
                       controller: bool = False, node: bool = False):
    """ Изменение пароля Postgres через Puppet не работает. """
    if isinstance(password, str):
        puppet_eyaml_common(key='pgsql_db_password', value=password)
        ret = get_output(f"{ROLE_SCRIPT_PATH} -a full", timeout=300)
        if not ret['result']:
            raise CommandExecutionError(ret['comment'])
        ret = get_output(f"sudo -u postgres psql -U postgres -d {db_name} "
                         f"-c \"alter user {db_user} with password '{password}';\"")
        if not ret['result']:
            raise CommandExecutionError(ret['comment'])
        restart_services(controller, node)
        return 'Data base password successfully changed.'


@states_response
def change_redis_password(password: str = None, controller: bool = False, node: bool = False):
    """
    Изменения пароля Redis через Puppet.
    ручной вариант:
        cur_pass = get_password(name='redis') or 'bazalt'
        os.system(f"redis-cli -a {cur_pass} config set requirepass \"{password}\"")
    """
    if isinstance(password, str):
        puppet_eyaml_common(key='redis_db_password', value=password)
        ret = get_output(f"{ROLE_SCRIPT_PATH} -a full", timeout=300)
        if not ret['result']:
            raise CommandExecutionError(ret['comment'])
        restart_services(controller, node)
        return 'Redis password successfully changed.'
